<?php
namespace Ems\portalGestor\Controller;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\{ Message, Error };
use Zeedhi\Framework\DataSource\DataSet;

use Ems\portalGestor\Service\IntervaloService;

class IntervaloController {

    /** @var IntervaloService */
    protected $intervaloService;

    public function __construct(
        IntervaloService $intervaloService
    ) {
      $this->intervaloService  = $intervaloService;
    }

    public function insertIntervalo(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrOrg         = (int)    $row['NRORG'];
            $nrVinculo     = (int)    $row['NRVINCULOM'];
            $date          = (string) $row['DATE'];
            $time          = (string) $row['HORARIO'];
            $before        = (bool)   $row['BEFORE'];
            $ocorrenciaRow = (array)  $row['ocorrencia'];

            $status = $this->intervaloService->insertIntervalo(
                $nrOrg, $nrVinculo, $date,
                $time, $before, $ocorrenciaRow
            );

            $success = $status['success'];

            if ($success) {
                $dataSet = [
                    'success' => $success
                ];

                $response->addDataSet(new DataSet('data', $dataSet));
            } else {
                $response->addMessage(new Message($status['message'], Message::TYPE_ERROR));
            }

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteIntervalo(
        Request\Row $request,
        Response    $response
    ) {
        try {
            $row = $request->getRow();

            $nrOrg      = (int)    $row['NRORG'];
            $nrVinculo  = (int)    $row['NRVINCULOM'];
            $date       = (string) $row['DATE'];
            $hrInicio   = (string) $row['DTHRINICIO'];
            $hrFim      = (string) $row['DTHRFIM'];
            $before     = (bool)   $row['before'];

            $status = $this->intervaloService->deleteIntervalo(
                $nrOrg, $nrVinculo, $date,
                $hrInicio, $hrFim, $before
            );

            $success = $status['success'];

            if ($success) {
                $dataSet = [
                    'success' => $success
                ];

                $response->addDataSet(new DataSet('data', $dataSet));
            } else {
                $response->addMessage(new Message($status['message'], Message::TYPE_ERROR));
            }

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
}